@@ -107,8 +107,8 @@ class WebServer(objects.Thread):
 		return r3sponse.ResponseObject(response)
 	def app(self):
 		app = flask.Flask(__name__)
-		log = logging.getLogger('werkzeug')
-		log.disabled = True
+		cli = sys.modules['flask.cli']
+		cli.show_server_banner = lambda *x: None
 		@app.route('/get')
 		def get():
 			token = request.args.get('token')
@@ -150,6 +150,10 @@ class WebServer(objects.Thread):
 			if token != self.token():
 				return r3sponse.error_response(f"Provided an invalid token {token}.").json()
 			return r3sponse.success_response(f"Active.").json()
+		#def run__(self, app, host, port):
+		#	app.run(host=host, port=port)
+		#self.process = multiprocessing.Process(target=app.run, args=(self, app, self.host,self.port,))
+		#self.process.start()
 		app.run(host=self.host, port=self.port)
 	def token(self):
 		if random.randrange(1, 100) <= 5: 
@@ -169,3 +173,6 @@ class WebServer(objects.Thread):
 		self.__cache__.set(group=self.id, id="token", data=Formats.String("").generate(length=64, digits=True, capitalize=True))
 		self.app()
 		self.__cache__.set(group=self.id, id="daemon", data="*stopped*")
+	#def stop(self):
+	#	self.process.terminate()
+	#	self.process.join()
